@@ -17,7 +17,7 @@ class ClusterConfig:
 
 class PlatoConfig(object):
     def __init__(self):
-        self.plato_install_path = os.getenv("PLATO_PATH", "")
+        self.plato_install_path = os.getenv("PLATO_PATH", "/opt/app-root/src/plato")
 
 
 plato_config = PlatoConfig()
